@@ -10,7 +10,7 @@ use Exporter;
 use SelfLoader;
 use vars qw { $VERSION @ISA %EXPORT_TAGS };
 
-$VERSION = '1.82';
+$VERSION = '1.84';
 @ISA		= qw ( Exporter );
 		     
 %EXPORT_TAGS	= ( ALL => [ qw(
@@ -57,6 +57,7 @@ sub _succeed
 	$@ = undef;
 	my ($wantarray,$textref) = splice @_, 0, 2;
 	my ($extrapos, $extralen) = @_>18 ? splice(@_, -2, 2) : (0,0);
+	my ($startlen) = $_[5];
 	my $remainderpos = $_[2];
 	if ($wantarray)
 	{
@@ -66,7 +67,7 @@ sub _succeed
 			push @res, substr($$textref,$from,$len);
 		}
 		if ($extralen) {	# CORRECT FILLET
-			my $extra = substr($res[0], $extrapos, $extralen, "\n");
+			my $extra = substr($res[0], $extrapos-$startlen, $extralen, "\n");
 			$res[1] = "$extra$res[1]";
 			eval { substr($$textref,$remainderpos,0) = $extra;
 			       substr($$textref,$extrapos,$extralen,"\n")} ;
@@ -81,7 +82,7 @@ sub _succeed
 	else
 	{
 		my $match = substr($$textref,$_[0],$_[1]);
-		substr($match,$extrapos-$_[0],$extralen,"") if $extralen;
+		substr($match,$extrapos-$_[0]-$startlen,$extralen,"") if $extralen;
 		my $extra = $extralen
 			? substr($$textref, $extrapos, $extralen)."\n" : "";
 		eval {substr($$textref,$_[4],$_[1]+$_[5])=$extra} ;	#CHOP OUT PREFIX & MATCH, IF POSSIBLE
@@ -232,7 +233,7 @@ sub _match_bracketed($$$$$$)	# $textref, $pre, $ldel, $qdel, $quotelike, $rdel
 		}
 		elsif ($qdel && $$textref =~ m/\G([$qdel])/gc)
 		{
-			$$textref =~ m/\G[^\\$1]*(?:\\.[^\\$1]*)*(\Q$1\E)/gc and next;
+			$$textref =~ m/\G[^\\$1]*(?:\\.[^\\$1]*)*(\Q$1\E)/gsc and next;
 			_failmsg "Unmatched embedded quote ($1)",
 				 pos $$textref;
 			pos $$textref = $startpos;
@@ -666,7 +667,7 @@ sub _match_quotelike($$$$)	# ($textref, $prepat, $allow_raw_match)
 		     || $rawmatch && $initial =~ m|^/|
 		     || $qmark && $initial =~ m|^\?|)
 	{
-		unless ($$textref =~ m/ \Q$initial\E [^\\$initial]* (\\.[^\\$initial]*)* \Q$initial\E /gcx)
+		unless ($$textref =~ m/ \Q$initial\E [^\\$initial]* (\\.[^\\$initial]*)* \Q$initial\E /gcsx)
 		{
 			_failmsg qq{Did not find closing delimiter to match '$initial' at "} .
 				     substr($$textref, $oppos, 20) .
@@ -716,8 +717,11 @@ sub _match_quotelike($$$$)	# ($textref, $prepat, $allow_raw_match)
 		if ($$textref =~ m{\G([A-Za-z_]\w*)}gc) {
 			$label = $1;
 		}
-		elsif ($$textref =~ m{\G(['"`])([^\1\\]*(?:\\.[^\1\\]*)*)\1}gc) {
-			$label = $2;
+		elsif ($$textref =~ m{ \G ' ([^'\\]* (?:\\.[^'\\]*)*) '
+				     | \G " ([^"\\]* (?:\\.[^"\\]*)*) "
+				     | \G ` ([^`\\]* (?:\\.[^`\\]*)*) `
+				     }gcsx) {
+			$label = $+;
 		}
 		else {
 			$label = "";
@@ -772,7 +776,7 @@ sub _match_quotelike($$$$)	# ($textref, $prepat, $allow_raw_match)
 	}
 	else
 	{
-		$$textref =~ /$ldel1[^\\$ldel1]*(\\.[^\\$ldel1]*)*$ldel1/gc
+		$$textref =~ /$ldel1[^\\$ldel1]*(\\.[^\\$ldel1]*)*$ldel1/gcs
 		|| do { pos $$textref = $startpos; return };
 	}
 	$ld2pos = $rd1pos = pos($$textref)-1;
@@ -807,7 +811,7 @@ sub _match_quotelike($$$$)	# ($textref, $prepat, $allow_raw_match)
 		}
 		else
 		{
-			$$textref =~ /[^\\$ldel2]*(\\.[^\\$ldel2]*)*$ldel2/gc
+			$$textref =~ /[^\\$ldel2]*(\\.[^\\$ldel2]*)*$ldel2/gcs
 			|| do { pos $$textref = $startpos; return };
 		}
 		$rd2pos = pos($$textref)-1;
